# Popgetter

Popgetter is a tool which downloads census data across different territories /
jurisdictions, converts them to a common format, and uploads them in cloud
storage.

The present documentation focuses on the _data pipeline_, i.e. how to prepare
the data. It does not tell you how to subsequently consume the data. If you are
a user who is more interested in using the data for your own projects, please
refer to the
[`popgetter-cli`](https://github.com/Urban-Analytics-Technology-Platform/popgetter-cli)
repository.
